# Information Extraction Evaluation Toolkit

## Documentation

The official documentation for this project is available at <https://ner.pages.teklia.com/metrics/ie-eval>.

## Get started

To install this package or to get started with development for this project, visit the related [section](https://ner.pages.teklia.com/metrics/ie-eval/get_started) in the documentation.
